import base64
from nicegui import ui


def encode_string(string):
    """
    Encode the string using base64 and ensure that the encoded result is of string type.

    Args:
    String: The string to be encoded.

    Returns:
    The encoded string.
    """

    encoded_bytes = base64.b64encode(string.encode("utf-8"))
    encoded_string = encoded_bytes.decode("utf-8")
    return encoded_string


def initMarkdownPreViewerDependence():
    """load  Dependence in page, !YOU NEED LOAD BEFORE PAGE FIRST LOAD!"""
    ui.add_head_html(
        """<link rel="stylesheet" href="https://unpkg.com/vditor/dist/index.css" />
<script src="https://unpkg.com/vditor/dist/index.min.js"></script>"""
    )


class MarkdownPreViewer(ui.element):

    def __init__(self):
        super().__init__()
        preview = ui.html("")
        id = "preview" + str(preview.id)
        self.preview_id = id
        preview.set_content(f"""<div id="{id}" class="w-full"></div>""")

    def render(
        self,
        markdown: str,
        cdn: str = "https://cdn.jsdelivr.net/npm/vditor",
        anchor: int = 0,
    ):
        """
        render markdown in preViewer

        Args:
        markdown: the origin markdown to render
        optional:
        cdn(optional): use which cdn to load the vditor
        more to see: https://ld246.com/article/1549638745630#options-preview
        """
        select_div = f'const el = document.getElementById("{self.preview_id}");\n'
        rebuild = (
            f"markdown=decodeURIComponent(escape(atob('{ encode_string(markdown) }')));"
        )
        render = (
            'Vditor.preview(el,markdown,{ cdn: "'
            + cdn
            + '", anchor: '
            + str(anchor)
            + " });\n"
        )
        ui.run_javascript(select_div + rebuild + render)



import base64
from nicegui import ui


class DropDetectArera(ui.card):
    def __init__(self):
        super().__init__()
        dropfile = ui.html("")
        id = "drop" + str(dropfile.id)
        self.dropfile = id
        dropfile.set_content(f"""<div id="{id}"></div>""")
        
        self.component(dropfile)

    def start_monitor(self, backgroundColor="lightblue"):
        ui.run_javascript(
            f'const dr = document.getElementById("{self.id}");\n'
            + "dr.addEventListener('dragover', (event) => {"
            + "event.preventDefault();"
            + f'dr.style.backgroundColor = "{backgroundColor}";\n'
            + "});"
            + """dr.addEventListener('drop', (event) => {
  // 阻止默认行为
  event.preventDefault();
  // 设置拖放区域的样式恢复默认
  dr.style.backgroundColor = 'white';

  // 获取拖放的文件列表
  const files = event.dataTransfer.files;

  // 遍历文件列表
  for (const file of files) {
    // 处理文件，例如读取文件内容
    const reader = new FileReader();
    reader.onload = (e) => {
      // 文件内容
      console.log(e.target.result);
    };
    // 读取文件内容
    reader.readAsText(file);
  }
});

// 当鼠标离开拖放区域时
dr.addEventListener('dragleave', () => {
  // 设置拖放区域的样式恢复默认
  dr.style.backgroundColor = 'white';
});"""
        )
